Statistical Functions
=====================

.. https://docs.scipy.org/doc/scipy/reference/stats.html

Order statistics
----------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.amin
   cupy.amax
   cupy.nanmin
   cupy.nanmax
   cupy.percentile


Means and variances
-------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.average
   cupy.mean
   cupy.var
   cupy.std
   cupy.nanmean
   cupy.nanvar
   cupy.nanstd


Histograms
----------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.histogram
   cupy.bincount


Correlations
------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.corrcoef
   cupy.cov
   cupy.correlate
